@@ -2,14 +2,13 @@
 # Licensed under the MIT License. See LICENSE in the project root
 # for license information.
 
-from __future__ import absolute_import, division, print_function, unicode_literals
+from __future__ import annotations
+import typing
+
+if typing.TYPE_CHECKING:
+    __all__: list[str]
 
 __all__ = []
 
-import os
-
-# Force absolute path on Python 2.
-__file__ = os.path.abspath(__file__)
-
 access_token = None
 """Access token used to authenticate with this adapter."""
